@@ -1,5 +1,7 @@
 import pard.raw_python_dictionaries
+from pard.handling_3_letter_code_decorator import handling_3_letter_code
 
+@handling_3_letter_code
 def grantham(amino_acid_1: str, amino_acid_2: str) -> int:
     """
     :param amino_acid_1: 1 letter code of the first amino acid
